@@ -1,13 +1,12 @@
 from main import execute
-from tileset_analyzer.entities.job_param import JobParam, CompressionType, JobAction
+from tileset_analyzer.entities.job_param import JobParam, CompressionType, JobAction, TileScheme
 
 
-
-def run_mbtiles_analyze():
+def run_mbtiles_analyze(actions):
     src_path = 'data/maptiler-osm-2017-07-03-v3.6.1-us_virginia.mbtiles'
     temp_folder = 'tileset_analyzer/static/data'
-    scheme = 'TMS'
-    actions = [JobAction.PROCESS, JobAction.SERVE]
+    scheme = TileScheme.TMS
+    actions = actions
     compressed = True
     compression_type = CompressionType.GZIP
     job_param = JobParam(
@@ -17,14 +16,17 @@ def run_mbtiles_analyze():
         actions=actions,
         verbose=False,
         compressed=compressed,
-        compression_type=compression_type
+        compression_type=compression_type,
+        mbtiles_tbl='tiles,tile_row,tile_column,zoom_level,tile_data'
     )
     execute(job_param)
-def folder_tiles_analyze():
+
+
+def folder_tiles_analyze(actions):
     src_path = 'data/tiles/'
     temp_folder = 'tileset_analyzer/static/data'
-    scheme = 'XYZ'
-    actions = [JobAction.PROCESS, JobAction.SERVE]
+    scheme = TileScheme.XYZ
+    actions = actions
     compressed = False
     compression_type = None
     job_param = JobParam(
@@ -34,16 +36,13 @@ def folder_tiles_analyze():
         actions=actions,
         verbose=False,
         compressed=compressed,
-        compression_type=compression_type
+        compression_type=compression_type,
+        folder_path_scheme='{z}/{x}/{y}.pbf',
+        mbtiles_tbl=None
     )
     execute(job_param)
 
 
 if __name__ == "__main__":
-    # run_mbtiles_analyze()
-    folder_tiles_analyze()
-
-
-
-
-
+    run_mbtiles_analyze([JobAction.PROCESS, JobAction.SERVE])
+    # folder_tiles_analyze([JobAction.PROCESS, JobAction.SERVE])
