@@ -12,8 +12,12 @@ def execute(job_param: JobParam):
     print('started...')
     print('src_path:', job_param.source)
     print('scheme:', job_param.scheme)
+    print('compressed:', job_param.compressed)
+    print('compression_type:', job_param.compression_type)
     print('temp_folder:', job_param.temp_folder)
     print('actions', job_param.actions)
+    print('folder_path_scheme', job_param.folder_path_scheme)
+    print('mbtiles_tbl', job_param.mbtiles_tbl)
     print('verbose', job_param.verbose)
 
     if 'process' in job_param.actions:
@@ -52,6 +56,9 @@ def cli():
     parser.add_argument('--temp_folder', help='temp_folder', required=True)
     parser.add_argument('--actions', help='actions', default=[JobAction.PROCESS, JobAction.SERVE])
     parser.add_argument("--verbose", help="increase output verbosity", action="store_false")
+    parser.add_argument('--folder_path_scheme', help='folder path scheme', default=None)
+    parser.add_argument('--mbtiles_tbl', help='mbtiles tbl params', default='tiles,tile_row,tile_column,zoom_level,tile_data')
+
     args = parser.parse_args()
     actions = args.actions.split(',')
 
@@ -62,11 +69,13 @@ def cli():
         actions=actions,
         verbose=args.verbose,
         compressed=args.compressed,
-        compression_type=args.compression_type)
+        compression_type=args.compression_type,
+        folder_path_scheme=args.folder_path_scheme,
+        mbtiles_tbl=args.mbtiles_tbl)
     execute(job_param)
 
 
 '''
 if __name__ == "__main__":
    cli()
-'''
+'''
\ No newline at end of file
